@@ -111,6 +111,15 @@ def test_info_quiet():
     assert result.exit_code == 0
 
 
+def test_info_gcps():
+    runner = CliRunner()
+    result = runner.invoke(main_group, [
+        'info',
+        'tests/data/white-gemini-iv.vrt'
+    ])
+    assert result.exit_code == 0
+
+
 def test_info_count():
     runner = CliRunner()
     result = runner.invoke(
@@ -257,7 +266,7 @@ def test_bounds_defaults():
         'tests/data/RGB.byte.tif'
     ])
     assert result.exit_code == 0
-    assert 'FeatureCollection' in result.output
+    assert 'Feature' in result.output
 
 
 def test_bounds_err():
